﻿#region References
using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Editors;
using System.Windows.Data;
#endregion

namespace InfragisticPOC
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>   
    public partial class MainWindow : Window
    {
        #region Private Methods
        private bool _isForward = false;
        private string NoSelection = "<No selection>";
        ClientStaffList clientStaffList = new ClientStaffList();
        private List<MyClass> objListStaffAssignments = new List<MyClass>();
        Guid _activeStaffGUID = Guid.Empty;
        private const string StrAddPositionLevel = "Add position level";
        private const string StrAddSelectedStaff = "Add selected staff";
        #endregion

        public MainWindow()
        {
            InitializeComponent();

            dpStaffAssignments.Loaded += new RoutedEventHandler(dpStaffAssignments_Loaded);
            dpStaffAssignments.InitializeRecord += new EventHandler<Infragistics.Windows.DataPresenter.Events.InitializeRecordEventArgs>(dpStaffAssignments_InitializeRecord);
            dpStaffAssignments.GotKeyboardFocus += new KeyboardFocusChangedEventHandler(dpStaffAssignments_GotKeyboardFocus);
          
            LoadStaffAssignmentGrid();
        }
             

        void dpStaffAssignments_Loaded(object sender, RoutedEventArgs e)
        {
            try
            {
                if (dpStaffAssignments.Records != null)
                {                    
                    if (dpStaffAssignments.Records.Count != 0)
                    {
                        foreach (DataRecord rec in dpStaffAssignments.Records)
                        {
                            rec.ExpansionIndicatorVisibility = Visibility.Collapsed;
                        }
                    }
                }
            }
            catch
            {
            }
        }
        
        void dpStaffAssignments_InitializeRecord(object sender, Infragistics.Windows.DataPresenter.Events.InitializeRecordEventArgs e)
        {
            DataRecord record = e.Record as DataRecord;
            if (record == null) return;
            if (record.DataItem != null && record.DataItem is MyClass)
            {
                record.Cells["SelectedStaff"].EditorStyle = GetUnBoundFieldStyle("SelectedStaff");
                record.Cells["Position"].EditorStyle = GetUnBoundFieldStyle("Position");
            }
        }

        private Style GetUnBoundFieldStyle(string columnname)
        {
            Binding selectedValBinding, textBinding;
            Style style = new Style(typeof(Infragistics.Windows.Editors.XamTextEditor));
            ControlTemplate controlTemplate = new ControlTemplate();
            controlTemplate.TargetType = typeof(Infragistics.Windows.Editors.XamTextEditor);
            FrameworkElementFactory frameworkElementFactory = new FrameworkElementFactory();
            FrameworkElementFactory stackPanelframeworkElementFactory = new FrameworkElementFactory(typeof(StackPanel));
            
            frameworkElementFactory = new FrameworkElementFactory(typeof(ComboBox));
            frameworkElementFactory.SetValue(ComboBox.ItemsSourceProperty, GetDropDownListData(columnname));
            if (columnname.Equals("SelectedStaff"))
            {
                frameworkElementFactory.AddHandler(ComboBox.SelectionChangedEvent, new SelectionChangedEventHandler(OnAreaOfStaffSelectionChanged));
                frameworkElementFactory.AddHandler(ComboBox.PreviewMouseLeftButtonDownEvent, new MouseButtonEventHandler(OnAreaOfStaffClick));
            }
            else
            {
                frameworkElementFactory.AddHandler(ComboBox.SelectionChangedEvent, new SelectionChangedEventHandler(OnAreaOfPositionChanged));
                frameworkElementFactory.AddHandler(ComboBox.PreviewMouseLeftButtonDownEvent, new MouseButtonEventHandler(OnAreaOfPositionClick));
            }
            frameworkElementFactory.SetValue(ComboBox.IsEnabledProperty, true);
            frameworkElementFactory.SetValue(ComboBox.IsEditableProperty, false);

            selectedValBinding = new Binding("Text");
            selectedValBinding.RelativeSource = new RelativeSource(RelativeSourceMode.TemplatedParent);
            selectedValBinding.Mode = BindingMode.TwoWay;
            frameworkElementFactory.SetBinding(ComboBox.SelectedValueProperty, selectedValBinding);
            textBinding = new Binding("Text");
            textBinding.RelativeSource = new RelativeSource(RelativeSourceMode.TemplatedParent);
            textBinding.Mode = BindingMode.TwoWay;

            stackPanelframeworkElementFactory.AppendChild(frameworkElementFactory);

            controlTemplate.VisualTree = stackPanelframeworkElementFactory;
            Setter setterBase = new Setter(ValueEditor.EditTemplateProperty, controlTemplate);
            style.Setters.Add(setterBase);

            return style;

        }

        void OnAreaOfStaffSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (((System.Windows.Controls.Primitives.Selector)(sender)).SelectedIndex <= 0)
                return;
            int index = dpStaffAssignments.SelectedItems.DataPresenter.ActiveRecord.Index;
            DataRecord rec = dpStaffAssignments.Records[index] as DataRecord;
            string employeeData = string.Empty;
            string employeePositionData = string.Empty;

            Guid areaOfExpertiseGuid = Guid.Empty;
            Guid areaOfExpertiseLevelGuid = Guid.Empty;
                                  
            if (index >= 0)
            {
                employeePositionData = rec.Cells[2].Value.ToString();
                employeeData = ((System.Windows.Controls.Primitives.Selector)(sender)).SelectedItem.ToString();
                if (!employeeData.Equals(NoSelection))
                {
                    rec.Cells[1].Value = employeeData;
                    rec.Cells[2].Value = employeePositionData;
                    rec.Cells[3].Value = "Y";
                    rec.IsActive = true;
                }
                else
                {
                    rec.Cells[1].Value = NoSelection;
                    rec.Cells[2].Value = NoSelection;
                    rec.Cells[3].Value = "";
                    rec.IsActive = true;
                }
            }
            blbBannerMessage.Content = "SelectedIndex: " + dpStaffAssignments.SelectedItems.DataPresenter.ActiveRecord.Index.ToString();
        }

        void OnAreaOfStaffClick(object sender, MouseButtonEventArgs e)
        {
            try
            {
                int index = dpStaffAssignments.SelectedItems.DataPresenter.ActiveRecord.Index;
                DataRecord rec = dpStaffAssignments.Records[index] as DataRecord;
                if (rec.Cells[1].Value.Equals(StrAddSelectedStaff))
                {
                    rec.Cells[2].Value = StrAddPositionLevel;
                }

            }
            catch (Exception ex)
            {
            }
        }

        void OnAreaOfPositionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (((System.Windows.Controls.Primitives.Selector)(sender)).SelectedIndex <= 0)
                return;
            int index = dpStaffAssignments.SelectedItems.DataPresenter.ActiveRecord.Index;
            DataRecord rec = dpStaffAssignments.Records[index] as DataRecord;
            string employeeData = string.Empty;
            string employeePositionData = string.Empty;
                        
            if (index >= 0)
            {
                employeeData = rec.Cells[1].Value.ToString();
                employeePositionData = ((System.Windows.Controls.Primitives.Selector)(sender)).SelectedItem.ToString();
                if (!employeeData.Equals(NoSelection))
                {
                    rec.Cells[2].Value = employeeData;
                    rec.Cells[3].Value = "Y";
                    rec.IsActive = true;
                    if (objListStaffAssignments.Count < 3)
                    {
                        AddToobjListStaffAssignments(rec.Cells[0].Value.ToString(), employeeData, employeePositionData);
                        dpStaffAssignments.DataSource = null;
                        dpStaffAssignments.DataSource = objListStaffAssignments;
                    }
                }
                blbBannerMessage.Content = "SelectedIndex: " + index.ToString();
            }
        }

        void OnAreaOfPositionClick(object sender, MouseButtonEventArgs e)
        {
            try
            {
                int index = dpStaffAssignments.SelectedItems.DataPresenter.ActiveRecord.Index;
                DataRecord rec = dpStaffAssignments.Records[index] as DataRecord;
                if (rec.Cells[1].Value.Equals(NoSelection) || rec.Cells[1].Value.Equals(StrAddSelectedStaff))
                {
                    rec.Cells[2].Value = StrAddPositionLevel;
                    rec.Cells[1].Value = StrAddSelectedStaff;
                    rec.Cells[1].IsActive = true;
                }
                else
                {
                    rec.Cells[3].Value = "";
                }

            }
            catch (Exception ex)
            {
            }
        }

        private void AddToobjListStaffAssignments(string description, string selectedStaff, string position)
        {
            objListStaffAssignments.Add(new MyClass() { ClientStaffList = clientStaffList, Description = description, SelectedStaff = selectedStaff, Position = position, Selected = "Y" });
        }
       
        
        void dpStaffAssignments_GotKeyboardFocus(object sender, KeyboardFocusChangedEventArgs e)
        {
            try
            {
                if (dpStaffAssignments.Records != null && dpStaffAssignments.Records.Count > 0)
                {
                    if (e.OriginalSource is XamDataGrid && _isForward)
                    {
                        ((DataRecord)dpStaffAssignments.Records[0]).Cells[0].IsActive = true;
                        _isForward = false;
                    }
                }
            }
            catch { }
        }

        void LoadStaffAssignmentGrid()
        {

            try
            {               
                Guid guid=new Guid("00000000-0000-0000-0000-000000000000");
                clientStaffList = new ClientStaffList();
                clientStaffList.Add(new ClientStaff() { StaffGuid = guid, StaffName = "<No selection>" });

                objListStaffAssignments = new List<MyClass>();
                objListStaffAssignments.Add(new MyClass() { ClientStaffList = clientStaffList, Description = "Primary Partner", SelectedStaff = "<No selection>", Position = "<No selection>", Selected = "" });

                if (rbnSenario2.IsChecked == true)
                {
                    objListStaffAssignments.Add(new MyClass() { Description = "Manager", SelectedStaff = "Manjunath", Position = "2", Selected = "" });
                    objListStaffAssignments.Add(new MyClass() { Description = "RegManager", SelectedStaff = "<No selection>", Position = "<No selection>", Selected = "" });
                }
                

                dpStaffAssignments.DataSource = null;
                dpStaffAssignments.DataSource = objListStaffAssignments;                
            }
            catch (Exception exception)
            {

            }
        }

        private void btnRefresh_Click(object sender, RoutedEventArgs e)
        {
            LoadStaffAssignmentGrid();
            blbBannerMessage.Content = "";
        }

        private List<string> GetDropDownListData(string columnname)
        {
            List<string> _operandData = new List<string>();
            _operandData.Add(NoSelection);
            if (columnname.Equals("SelectedStaff"))
            {
                _operandData.Add("Robert");
                _operandData.Add("Manjunath");
                _operandData.Add("Ravin");
            }
            else
            {
                _operandData.Add("1");
                _operandData.Add("2");
                _operandData.Add("3");
            }
            return _operandData;
        }

        private void btnCancel_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }
    }

    #region Resource
    public class MyClass
    {
        private string _description;
        private string _selectedStaff;
        private string _position;
        private string _selected;
        private ClientStaffList _clientStaffList; 
        public MyClass() 
        {             
        }
        public ClientStaffList ClientStaffList
        {
            get { return _clientStaffList; }
            set { _clientStaffList = value; }
        }
        public string Description 
        {
            get { return _description; }
            set { _description = value; } 
        }
        public string SelectedStaff
        {
            get { return _selectedStaff; }
            set { _selectedStaff = value; }
        }
        public string Position
        {
            get { return _position; }
            set { _position = value; }
        }
        public string Selected
        {
            get { return _selected; }
            set { _selected = value; }
        } 
    }

    public class ClientStaff
    {

        public ClientStaff()
        {

        }

        private Guid _staffGuidField;
        public Guid StaffGuid
        {
            get { return _staffGuidField; }
            set { _staffGuidField = value; }
        }

        private string _staffName;
        public string StaffName
        {
            get { return _staffName; }
            set { _staffName = value; }
        }

        public override string ToString()
        {
            return _staffName;
        }

    }

    public class ClientStaffList : System.Collections.ObjectModel.ObservableCollection<ClientStaff>
    {

    }
    #endregion
}
